Module: MapFish::Print
- Defined in:
- lib/print.rb
Defined Under Namespace
Modules: Controller Classes: JavaError
Class Method Summary collapse
-
.add_routes(map, controller = 'print', base = 'print') ⇒ Object
Used to add the needed routes for the print module.
Class Method Details
.add_routes(map, controller = 'print', base = 'print') ⇒ Object
Used to add the needed routes for the print module
34 35 36 37 38 |
# File 'lib/print.rb', line 34 def self.add_routes(map, controller = 'print', base = 'print') map.connect(base+'/info.:format', :controller=>controller, :action=>'info', :method=>:get) map.connect(base+'/create.:format', :controller=>controller, :action=>'create', :method=>:post) map.connect(base+'/:id.:format', :controller=>controller, :action=>'show', :method=>:get) end |